@@ -185,10 +185,7 @@ class Core(base.Core):
         self.conn.finalize()
 
     def get_screen_info(self) -> list[ScreenRect]:
-        ps = self.conn.pseudoscreens
-        if self.qtile:
-            self._xpoll()
-        return ps
+        return self.conn.pseudoscreens
 
     @property
     def wmname(self):
@@ -274,6 +271,7 @@ class Core(base.Core):
 
             self.update_client_lists()
             win.change_layer()
+            self.conn.enable_screen_change_notifications()
 
     def warp_pointer(self, x, y):
         self._root.warp_pointer(x, y)
@@ -479,11 +477,17 @@ class Core(base.Core):
 
     def lookup_key(self, key: config.Key | config.KeyChord) -> tuple[int, int]:
         """Find the keysym and the modifier mask for the given key"""
-        try:
-            keysym = xcbq.get_keysym(key.key)
-            modmask = xcbq.translate_masks(key.modifiers)
-        except xcbq.XCBQError as err:
-            raise utils.QtileError(err)
+        if isinstance(key.key, str):
+            keysym = xcbq.keysyms.get(key.key.lower())
+            if not keysym:
+                raise utils.QtileError("Unknown keysym: %s" % key.key)
+
+        else:
+            keysym = self.conn.code_to_syms[key.key][0]
+            if not keysym:
+                raise utils.QtileError("Unknown keycode: %s" % key.key)
+
+        modmask = xcbq.translate_masks(key.modifiers)
 
         return keysym, modmask
 
@@ -645,7 +649,6 @@ class Core(base.Core):
 
     def handle_KeyPress(self, event, *, simulated=False) -> None:  # noqa: N802
         assert self.qtile is not None
-
         keysym = self.conn.code_to_syms[event.detail][0]
         key, handled = self.qtile.process_key_event(keysym, event.state & self._valid_mask)
 
